@@ -1,21 +1,8 @@
 /*
-    Copyright (C) 2013 Mark Gaiser <markg85@gmail.com>
-    Copyright (C) 2016 Martin Klapetek <mklapetek@kde.org>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+    SPDX-FileCopyrightText: 2013 Mark Gaiser <markg85@gmail.com>
+    SPDX-FileCopyrightText: 2016 Martin Klapetek <mklapetek@kde.org>
 
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "daysmodel.h"
@@ -72,6 +59,10 @@ QVariant DaysModel::data(const QModelIndex &index, int role) const
             return currentData.isCurrent;
         case containsEventItems:
             return m_eventsData.contains(currentDate);
+        case containsMajorEventItems:
+            return hasMajorEventAtDate(currentDate);
+        case containsMinorEventItems:
+            return hasMinorEventAtDate(currentDate);
         case dayNumber:
             return currentData.dayNumber;
         case monthNumber:
@@ -94,13 +85,14 @@ void DaysModel::update()
     const QDate modelFirstDay(m_data->at(0).yearNumber, m_data->at(0).monthNumber, m_data->at(0).dayNumber);
 
     if (m_pluginsManager) {
-        Q_FOREACH (CalendarEvents::CalendarEventsPlugin *eventsPlugin, m_pluginsManager->plugins()) {
+        const auto plugins = m_pluginsManager->plugins();
+        for (CalendarEvents::CalendarEventsPlugin *eventsPlugin : plugins) {
             eventsPlugin->loadEventsForDateRange(modelFirstDay, modelFirstDay.addDays(42));
         }
     }
 
     // We always have 42 items (or weeks * num of days in week) so we only have to tell the view that the data changed.
-    emit dataChanged(index(0, 0), index(m_data->count() - 1, 0));
+    Q_EMIT dataChanged(index(0, 0), index(m_data->count() - 1, 0));
 }
 
 void DaysModel::onDataReady(const QMultiHash<QDate, CalendarEvents::EventData> &data)
@@ -112,8 +104,9 @@ void DaysModel::onDataReady(const QMultiHash<QDate, CalendarEvents::EventData> &
         m_agendaNeedsUpdate = true;
     }
 
-    // only the containsEventItems role may have changed
-    emit dataChanged(index(0, 0), index(m_data->count() - 1, 0), {containsEventItems});
+    // only the containsEventItems roles may have changed
+    Q_EMIT dataChanged(index(0, 0), index(m_data->count() - 1, 0),
+                     {containsEventItems, containsMajorEventItems, containsMinorEventItems});
 
     Q_EMIT agendaUpdated(QDate::currentDate());
 }
@@ -135,10 +128,11 @@ void DaysModel::onEventModified(const CalendarEvents::EventData &data)
         m_agendaNeedsUpdate = true;
     }
 
-    Q_FOREACH (const QDate date, updatesList) {
+    for (const QDate date : qAsConst(updatesList)) {
         const QModelIndex changedIndex = indexForDate(date);
         if (changedIndex.isValid()) {
-            Q_EMIT dataChanged(changedIndex, changedIndex, {containsEventItems});
+            Q_EMIT dataChanged(changedIndex, changedIndex,
+                               {containsEventItems, containsMajorEventItems, containsMinorEventItems});
         }
         Q_EMIT agendaUpdated(date);
     }
@@ -161,10 +155,11 @@ void DaysModel::onEventRemoved(const QString &uid)
         m_agendaNeedsUpdate = true;
     }
 
-    Q_FOREACH (const QDate date, updatesList) {
+    for (const QDate date : qAsConst(updatesList)) {
         const QModelIndex changedIndex = indexForDate(date);
         if (changedIndex.isValid()) {
-            Q_EMIT dataChanged(changedIndex, changedIndex, {containsEventItems});
+            Q_EMIT dataChanged(changedIndex, changedIndex,
+                               {containsEventItems, containsMajorEventItems, containsMinorEventItems});
         }
         Q_EMIT agendaUpdated(date);
     }
@@ -188,7 +183,7 @@ QList<QObject*> DaysModel::eventsForDate(const QDate &date)
         return b.type() > a.type() || b.startDateTime() > a.startDateTime();
     });
 
-    Q_FOREACH (const CalendarEvents::EventData &event, events) {
+    for (const CalendarEvents::EventData &event : qAsConst(events)) {
         m_qmlData << new EventDataDecorator(event, this);
     }
 
@@ -210,6 +205,30 @@ QModelIndex DaysModel::indexForDate(const QDate &date)
     return createIndex(daysTo, 0);
 }
 
+bool DaysModel::hasMajorEventAtDate(const QDate &date) const
+{
+    auto it = m_eventsData.find(date);
+    while (it != m_eventsData.end() && it.key() == date) {
+        if (!it.value().isMinor()) {
+            return true;
+        }
+        ++it;
+    }
+    return false;
+}
+
+bool DaysModel::hasMinorEventAtDate(const QDate &date) const
+{
+    auto it = m_eventsData.find(date);
+    while (it != m_eventsData.end() && it.key() == date) {
+        if (it.value().isMinor()) {
+            return true;
+        }
+        ++it;
+    }
+    return false;
+}
+
 void DaysModel::setPluginsManager(QObject *manager)
 {
     EventPluginsManager *m = qobject_cast<EventPluginsManager*>(manager);
@@ -218,9 +237,9 @@ void DaysModel::setPluginsManager(QObject *manager)
         return;
     }
 
-    if (m_pluginsManager != 0) {
+    if (m_pluginsManager) {
         m_pluginsManager->deleteLater();
-        m_pluginsManager = 0;
+        m_pluginsManager = nullptr;
     }
 
     m_pluginsManager = m;
@@ -242,6 +261,8 @@ QHash<int, QByteArray> DaysModel::roleNames() const
     return {
         {isCurrent, "isCurrent"},
         {containsEventItems, "containsEventItems"},
+        {containsMajorEventItems, "containsMajorEventItems"},
+        {containsMinorEventItems, "containsMinorEventItems"},
         {dayNumber, "dayNumber"},
         {monthNumber, "monthNumber"},
         {yearNumber, "yearNumber"}
