@@ -1,21 +1,8 @@
 /*
- * Copyright (C) 2014  David Edmundson <davidedmundson@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    SPDX-FileCopyrightText: 2014 David Edmundson <davidedmundson@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "fadingnode_p.h"
 
@@ -36,7 +23,7 @@ class FadingMaterialShader : public QSGSimpleMaterialShader<FadingMaterialState>
 public:
     FadingMaterialShader();
     using QSGSimpleMaterialShader<FadingMaterialState>::updateState;
-    virtual void updateState(const FadingMaterialState* newState, const FadingMaterialState* oldState) override;
+    void updateState(const FadingMaterialState* newState, const FadingMaterialState* oldState) override;
     QList<QByteArray> attributes() const override;
 
     void initialize() override;
@@ -62,19 +49,19 @@ QList<QByteArray> FadingMaterialShader::attributes() const
 void FadingMaterialShader::updateState(const FadingMaterialState* newState, const FadingMaterialState* oldState)
 {
     if (!oldState || oldState->source != newState->source) {
-        glFuncs->glActiveTexture(GL_TEXTURE1);
+        glFuncs->glActiveTexture(GL_TEXTURE0);
         newState->source->bind();
         QRectF rect = newState->source->normalizedTextureSubRect();
         program()->setUniformValue(m_sourceRectId, QVector4D(rect.x(), rect.y(), rect.width(), rect.height()));
-        // reset the active texture back to 0 after we changed it to something else
-        glFuncs->glActiveTexture(GL_TEXTURE0);
     }
 
     if (!oldState || oldState->target != newState->target) {
-        glFuncs->glActiveTexture(GL_TEXTURE0);
+        glFuncs->glActiveTexture(GL_TEXTURE1);
         newState->target->bind();
         QRectF rect = newState->target->normalizedTextureSubRect();
         program()->setUniformValue(m_targetRectId, QVector4D(rect.x(), rect.y(), rect.width(), rect.height()));
+        // reset the active texture back to 0 after we changed it to something else
+        glFuncs->glActiveTexture(GL_TEXTURE0);
     }
 
     if (!oldState || oldState->progress != newState->progress) {
