@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright 2011 Viranch Mehta <viranch.mehta@gmail.com>                *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Viranch Mehta <viranch.mehta@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "qmenu.h"
 
@@ -37,7 +24,7 @@ QMenuProxy::QMenuProxy(QObject *parent)
       m_placement(Plasma::Types::LeftPosedTopAlignedPopup)
 {
     if (qobject_cast<QApplication *>(QCoreApplication::instance())) {
-        m_menu = new QMenu(0);
+        m_menu = new QMenu(nullptr);
         // Breeze and Oxygen have rounded corners on menus. They set this attribute in polish()
         // but at that time the underlying surface has already been created where setting this
         // flag makes no difference anymore (Bug 385311)
@@ -47,7 +34,7 @@ QMenuProxy::QMenuProxy(QObject *parent)
         connect(m_menu, &QMenu::triggered, this, &QMenuProxy::itemTriggered);
         connect(m_menu, &QMenu::aboutToHide, this, [ = ]() {
                 m_status = DialogStatus::Closed;
-                emit statusChanged();
+                Q_EMIT statusChanged();
         });
     }
 }
@@ -59,7 +46,11 @@ QMenuProxy::~QMenuProxy()
 
 QQmlListProperty<QMenuItem> QMenuProxy::content()
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    return QQmlListProperty<QMenuItem>(this, &m_items);
+#else
     return QQmlListProperty<QMenuItem>(this, m_items);
+#endif
 }
 
 int QMenuProxy::actionCount() const
@@ -91,7 +82,7 @@ void QMenuProxy::setVisualParent(QObject *parent)
     //if the old parent was a QAction, disconnect the menu from it
     QAction *action = qobject_cast<QAction *>(m_visualParent.data());
     if (action) {
-        action->setMenu(0);
+        action->setMenu(nullptr);
         m_menu->clear();
     }
     //if parent is a QAction, become a submenu
@@ -99,7 +90,7 @@ void QMenuProxy::setVisualParent(QObject *parent)
     if (action) {
         action->setMenu(m_menu);
         m_menu->clear();
-        foreach (QMenuItem *item, m_items) {
+        for (QMenuItem *item : qAsConst(m_items)) {
             if (item->section()) {
                 if (!item->isVisible()) {
                     continue;
@@ -114,7 +105,7 @@ void QMenuProxy::setVisualParent(QObject *parent)
     }
 
     m_visualParent = parent;
-    emit visualParentChanged();
+    Q_EMIT visualParentChanged();
 }
 
 QWindow *QMenuProxy::transientParent()
@@ -132,7 +123,7 @@ void QMenuProxy::setTransientParent(QWindow *parent)
     }
 
     m_menu->windowHandle()->setTransientParent(parent);
-    emit transientParentChanged();
+    Q_EMIT transientParentChanged();
 }
 
 Plasma::Types::PopupPlacement QMenuProxy::placement() const
@@ -145,7 +136,7 @@ void QMenuProxy::setPlacement(Plasma::Types::PopupPlacement placement)
     if (m_placement != placement) {
         m_placement = placement;
 
-        emit placementChanged();
+        Q_EMIT placementChanged();
     }
 }
 
@@ -159,7 +150,7 @@ void QMenuProxy::setMinimumWidth(int width)
     if (m_menu->minimumWidth() != width) {
         m_menu->setMinimumWidth(width);
 
-        emit minimumWidthChanged();
+        Q_EMIT minimumWidthChanged();
     }
 }
 
@@ -173,7 +164,7 @@ void QMenuProxy::setMaximumWidth(int width)
     if (m_menu->maximumWidth() != width) {
         m_menu->setMaximumWidth(width);
 
-        emit maximumWidthChanged();
+        Q_EMIT maximumWidthChanged();
     }
 }
 
@@ -255,6 +246,9 @@ void QMenuProxy::addMenuItem(QMenuItem *item, QMenuItem *before)
         m_menu->addAction(item->action());
         m_items << item;
     }
+    connect(item, &QMenuItem::destroyed, this, [this, item]() {
+        removeMenuItem(item);
+    });
 }
 
 void QMenuProxy::addSection(const QString &text)
@@ -274,13 +268,14 @@ void QMenuProxy::removeMenuItem(QMenuItem *item)
 
 void QMenuProxy::itemTriggered(QAction *action)
 {
-    QMenuItem *item = qobject_cast<QMenuItem *>(action);
-    if (item) {
-        emit triggered(item);
-        int index = m_items.indexOf(item);
-        if (index > -1) {
-            emit triggeredIndex(index);
+    for (int i = 0; i < m_items.count(); ++i) {
+        QMenuItem *item = m_items.at(i);
+        if (item->action() == action) {
+            Q_EMIT triggered(item);
+            Q_EMIT triggeredIndex(i);
+            break;
         }
+
     }
 }
 
@@ -288,7 +283,7 @@ void QMenuProxy::rebuildMenu()
 {
     m_menu->clear();
 
-    foreach (QMenuItem *item, m_items) {
+    for (QMenuItem *item : qAsConst(m_items)) {
         if (item->section()) {
             if (!item->isVisible()) {
                 continue;
@@ -336,7 +331,7 @@ void QMenuProxy::open(int x, int y)
     openInternal(pos.toPoint());
 }
 
-Q_INVOKABLE void QMenuProxy::openRelative()
+void QMenuProxy::openRelative()
 {
     QQuickItem *parentItem = nullptr;
 
@@ -458,7 +453,7 @@ void QMenuProxy::openInternal(QPoint pos)
 
     m_menu->popup(pos);
     m_status = DialogStatus::Open;
-    emit statusChanged();
+    Q_EMIT statusChanged();
 }
 
 QQuickItem *QMenuProxy::parentItem() const
