@@ -228,10 +228,14 @@ void DialogPrivate::updateTheme()
         q->setMask(QRegion());
         DialogShadows::self()->removeWindow(q);
     } else {
+        auto prefix = QStringLiteral("");
+        if ((backgroundHints & Dialog::SolidBackground) == Dialog::SolidBackground) {
+            prefix = QStringLiteral("solid/");
+        }
         if (type == Dialog::Tooltip) {
-            frameSvgItem->setImagePath(QStringLiteral("widgets/tooltip"));
+            frameSvgItem->setImagePath(prefix + QStringLiteral("widgets/tooltip"));
         } else {
-            frameSvgItem->setImagePath(QStringLiteral("dialogs/background"));
+            frameSvgItem->setImagePath(prefix + QStringLiteral("dialogs/background"));
         }
 
         KWindowEffects::enableBlurBehind(q->winId(), theme.blurBehindEnabled(), frameSvgItem->mask());
@@ -758,10 +762,14 @@ void DialogPrivate::applyType()
     if (backgroundHints == Dialog::NoBackground) {
         frameSvgItem->setImagePath(QString());
     } else {
+        auto prefix = QStringLiteral("");
+        if ((backgroundHints & Dialog::SolidBackground) == Dialog::SolidBackground) {
+            prefix = QStringLiteral("solid/");
+        }
         if (type == Dialog::Tooltip) {
-            frameSvgItem->setImagePath(QStringLiteral("widgets/tooltip"));
+            frameSvgItem->setImagePath(prefix + QStringLiteral("widgets/tooltip"));
         } else {
-            frameSvgItem->setImagePath(QStringLiteral("dialogs/background"));
+            frameSvgItem->setImagePath(prefix + QStringLiteral("dialogs/background"));
         }
     }
 
@@ -892,7 +900,7 @@ void Dialog::setMainItem(QQuickItem *mainItem)
         }
 
         //if this is called in Component.onCompleted we have to wait a loop the item is added to a scene
-        emit mainItemChanged();
+        Q_EMIT mainItemChanged();
     }
 }
 
@@ -913,7 +921,7 @@ void Dialog::setVisualParent(QQuickItem *visualParent)
     }
 
     d->visualParent = visualParent;
-    emit visualParentChanged();
+    Q_EMIT visualParentChanged();
     if (visualParent) {
         if (visualParent->window()) {
             setTransientParent(visualParent->window());
@@ -1067,7 +1075,7 @@ void Dialog::setLocation(Plasma::Types::Location location)
         return;
     }
     d->location = location;
-    emit locationChanged();
+    Q_EMIT locationChanged();
 
     if (d->mainItem) {
         d->syncToMainItemSize();
@@ -1090,7 +1098,7 @@ void Dialog::setFramelessFlags(Qt::WindowFlags flags)
         flags |= Qt::Dialog;
     setFlags(Qt::FramelessWindowHint | flags);
     d->applyType();
-    emit flagsChanged();
+    Q_EMIT flagsChanged();
 }
 
 void Dialog::adjustGeometry(const QRect &geom)
@@ -1140,7 +1148,7 @@ void Dialog::setType(WindowType type)
 
     d->type = type;
     d->applyType();
-    emit typeChanged();
+    Q_EMIT typeChanged();
 }
 
 Dialog::WindowType Dialog::type() const
@@ -1178,7 +1186,7 @@ void Dialog::focusOutEvent(QFocusEvent *ev)
 
         if (viewClicked || (!parentHasFocus && !childHasFocus)) {
             setVisible(false);
-            emit windowDeactivated();
+            Q_EMIT windowDeactivated();
         }
     }
 
@@ -1373,7 +1381,7 @@ void Dialog::setHideOnWindowDeactivate(bool hide)
         return;
     }
     d->hideOnWindowDeactivate = hide;
-    emit hideOnWindowDeactivateChanged();
+    Q_EMIT hideOnWindowDeactivateChanged();
 }
 
 bool Dialog::isOutputOnly() const
@@ -1387,7 +1395,7 @@ void Dialog::setOutputOnly(bool outputOnly)
         return;
     }
     d->outputOnly = outputOnly;
-    emit outputOnlyChanged();
+    Q_EMIT outputOnlyChanged();
 }
 
 void Dialog::setVisible(bool visible)
@@ -1406,7 +1414,7 @@ void Dialog::setVisible(bool visible)
         QQuickWindow::setVisible(visible);
         //signal will be emitted and proxied from the QQuickWindow code
     } else {
-        emit visibleChangedProxy();
+        Q_EMIT visibleChangedProxy();
     }
 }
 
@@ -1431,7 +1439,7 @@ void Dialog::setBackgroundHints(Dialog::BackgroundHints hints)
 
     d->backgroundHints = hints;
     d->updateTheme();
-    emit backgroundHintsChanged();
+    Q_EMIT backgroundHintsChanged();
 }
 
 }
